﻿using System.Collections.Generic;
using System.Transactions;
using DataAccess;

namespace BusinessLogic
{
    public class OrderController
    {
        private static IOrderRepository m_OrderRep = new LinqOrderRepository();

        public static IOrderRepository OrderRepository
        {
            get { return m_OrderRep; }
            set { m_OrderRep = value; }
        }

        private static IPaymentService m_PaymentService = new PaymentProcessingProxy();

        public static IPaymentService PaymentService
        {
            get { return m_PaymentService; }
            set { m_PaymentService = value;}
        }

        public static bool PlaceOrder(Order order, Payment p)
        {
            using (TransactionScope trans = new TransactionScope())
            {
                bool paymentResult = PaymentService.TakePayment(order, p);
                bool orderResult = OrderRepository.PlaceOrder(order);

                if (orderResult && paymentResult)
                {
                    trans.Complete();
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        public static Order GetOrder(int orderId)
        {
            return OrderRepository.GetOrder(orderId);
        }

        public static List<Order> GetOrdersForCustomer(Customer customer)
        {
            return OrderRepository.GetOrdersForCustomer(customer);
        }

        public static bool TakePayment(Order o, Payment p)
        {
            return m_PaymentService.TakePayment(o, p);
        }
    }
}
