﻿using System;
using System.Linq;
using System.Collections.Generic;
using DataAccess;

namespace BusinessLogic
{
    public static class ProductController
    {
        //Parameter Injection.  Allows us to inject the mock object during unit tests but leave
        //production code alone.
        //Even better to use an IoC Container!
        private static IProductRepository m_ProductRep = new LinqProductRepository();

        public static IProductRepository ProductRepository
        {
            get { return m_ProductRep; }
            set { m_ProductRep = value; }
        }

        #region Standard Methods
        public static List<Category> GetCategories()
        {
            return ProductRepository.GetCategories();
        }

        //public static Category GetCategory(string categoryTitle)
        //{
        //    return ProductRepository.GetCategory(categoryTitle);
        //}

        //public static List<Product> GetProductsForCategory(Category c)
        //{
        //    return ProductRepository.GetProductsForCategory(c);
        //}

        //public static Product GetProduct(int productID)
        //{
        //    return ProductRepository.GetProduct(productID);
        //}

        #endregion

        #region Standard Methods with Validation

        public static Product GetProduct(int productID)
        {
            if (productID <= 0)
                throw new ArgumentNullException("productID", "Product ID must be greater than 0");

            return ProductRepository.GetProduct(productID);
        }

        public static Category GetCategory(string categoryTitle)
        {
            if(string.IsNullOrEmpty(categoryTitle))
                throw new ArgumentNullException("categoryTitle", "Must enter a category title");

            return ProductRepository.GetCategory(categoryTitle);
        }

        public static List<Product> GetProductsForCategory(Category c)
        {
            if(c == null)
                throw new ArgumentNullException("c", "Category cannot be null");
                
            return ProductRepository.GetProductsForCategory(c);
        }

        #endregion

        public static Category FindCategoryByID(int categoryID)
        {
            return ProductRepository.GetCategories().Single(c => c.CategoryID == categoryID);

            //return ProductRepository.GetCategoryById(categoryID);
        }

        public static List<Product> GetAllProducts()
        {
            return ProductRepository.GetAllProducts();
        }
    }
}
