﻿using System;
using MbUnit.Framework;

namespace DataAccess.Tests
{
    [TestFixture]
    public class LinqOrderRepositoryTests
    {
        private LinqOrderRepository m_OrderRepository = null;

        [SetUp]
        public void Setup()
        {
            m_OrderRepository = new LinqOrderRepository();
        }

        [TearDown]
        public void TearDown()
        {
            m_OrderRepository = null;
        }

        [Test]
        [RollBack]
        public void GetOrder_ValidOrderInDatabase_PopulatedList()
        {
            Order o = TestHelper.InsertOrder();
            Order order = m_OrderRepository.GetOrder(o.OrderID);
            Assert.AreEqual(o.OrderID, order.OrderID);
        }


        [Test]
        [RollBack]
        public void PlaceOrder_CreateValidOrderWithOneDetail_UpdatesDatabase()
        {
            Order o = new Order();
            o.OrderID = 123;
            o.Customer = TestHelper.InsertCustomer();
            o.OrderDate = DateTime.Now;

            Order_Detail orderLine = new Order_Detail();
            orderLine.Order = o;
            orderLine.Product = TestHelper.InsertProduct(TestHelper.InsertCategory());
            orderLine.Quantity = 1;
            orderLine.UnitPrice = 123;

            o.Order_Details.Add(orderLine);
            
            m_OrderRepository.PlaceOrder(o);

            Order insertedOrder = m_OrderRepository.GetOrder(o.OrderID);
            Assert.IsNotNull(insertedOrder);
            Assert.AreEqual(o.CustomerID, insertedOrder.CustomerID);
            Assert.AreEqual(1, o.Order_Details.Count);
            Assert.AreEqual(orderLine.Product.ProductName, o.Order_Details[0].Product.ProductName);
        }

        [Test]
        [RollBack]
        public void GetOrderForCustomer_ValidCustomerWithOrder_ReturnsListOfOrders()
        {
            Customer  c = TestHelper.InsertCustomer();
            

        }
    }
}
