﻿using System.Collections.Generic;
using MbUnit.Framework;

namespace DataAccess.Tests
{
    [TestFixture]
    public class LinqProductRepositoryTests
    {
        private LinqProductRepository m_ProductRepository = null;

        [SetUp]
        public void Setup()
        {
            m_ProductRepository = new LinqProductRepository();
        }

        [TearDown]
        public void TearDown()
        {
            m_ProductRepository = null;
        }

        [Test]
        public void GetCategories_NoContent_ReturnEmptyList()
        {
            List<Category> categories = m_ProductRepository.GetCategories();
            Assert.IsNotNull(categories);
            Assert.AreEqual(0, categories.Count);
        }

        [Test]
        [RollBack]
        public void GetCategories_SimpleContent_ReturnPopulatedList()
        {
            Category testCategory = TestHelper.InsertCategory();

            List<Category> categories = m_ProductRepository.GetCategories();

            Assert.IsNotNull(categories);
            Assert.AreEqual(1, categories.Count);
            Assert.AreEqual(testCategory.CategoryName, categories[0].CategoryName);
        }

        [Test]
        [RollBack]
        public void GetCategoryByName_NameOfValidCategory_ReturnCategoryObject()
        {
            Category testCategory = TestHelper.InsertCategory();

            Category c = m_ProductRepository.GetCategory("Software");

            Assert.AreEqual(testCategory.CategoryName, c.CategoryName);
            Assert.AreEqual(testCategory.Description, c.Description);
        }

        [Test]
        [RollBack]
        public void GetProductsForCategory_ValidCategory_EmptyList()
        {
            Category testCategory = TestHelper.InsertCategory();

            List<Product> products = m_ProductRepository.GetProductsForCategory(testCategory);
            Assert.AreEqual(0, products.Count);
        }

        [Test]
        [RollBack]
        public void GetProductsForCateogry_ValidCategoryWithProduct_PopulatedList()
        {
            Category c = TestHelper.InsertCategory();
            Product p = TestHelper.InsertProduct(c);

            List<Product> products = m_ProductRepository.GetProductsForCategory(c);
            Assert.AreEqual(1, products.Count);
            Assert.AreEqual(p.ProductName, products[0].ProductName);
        }

        [Test]
        [RollBack]
        public void GetProductByID_ValidProductID_ReturnProductID()
        {
            Category sampleC = TestHelper.InsertCategory();
            Product sampleP = TestHelper.InsertProduct(sampleC);

            Product p = m_ProductRepository.GetProduct(sampleP.ProductID);

            Assert.AreEqual(p.ProductName, sampleP.ProductName);
            Assert.AreEqual(p.CategoryID, sampleC.CategoryID);
        }


        [Test]
        [RollBack]
        public void GetCategoryByID_ValidCategoryID_ReturnCategoryID()
        {
            Category expected = TestHelper.InsertCategory();

            Category actual = m_ProductRepository.GetCategoryById(expected.CategoryID);

            //Assert.AreEqual(expected, actual);
            Assert.AreEqual(expected.CategoryName, actual.CategoryName);
        }

        public void GetAllProducts_ValidProductID_ReturnProductList()
        {
            Category sampleC = TestHelper.InsertCategory();
            Product sampleP = TestHelper.InsertProduct(sampleC);

            List<Product> ps = m_ProductRepository.GetAllProducts();

            Assert.AreEqual(1, ps.Count);
        }

    }
}
