﻿using System;
using System.Linq;
using MbUnit.Framework;

namespace DataAccess.Tests.Other
{
    [TestFixture]
    public class ProblemsWithRollback
    {
        [Test]
        [RollBack]
        public void InsertOrder()
        {
            TestingApplicationsWithMbUnitDataContext db = new TestingApplicationsWithMbUnitDataContext();
         
            int count = db.Orders.Count();
            Console.WriteLine("Count in table: " + count);

            Order o = TestHelper.InsertOrder();
            //Assert.AreEqual(1, o.OrderID);
            Console.WriteLine(o.OrderID);
        }
    }

    [TestFixture]
    public class ProblemsWithRollback_TRUNCATE
    {
        //Reason why I'm executing script is incase other tests do not clean up
        //after themselves or expect the database to be empty        
        [SetUp]
        public void Setup()
        {
            TestingApplicationsWithMbUnitDataContext db = new TestingApplicationsWithMbUnitDataContext();
            db.ExecuteCommand("TRUNCATE TABLE [Order Details]", "");
            //db.ExecuteCommand("TRUNCATE TABLE Orders", "");  Cannot do this as it is referenced by a Foreign key
            db.ExecuteCommand("DELETE FROM Orders", "");
            db.ExecuteCommand("DELETE FROM Products", "");
            db.ExecuteCommand("DELETE FROM Categories", "");
        }

        [TearDown]
        public void Teardown()
        {
            TestingApplicationsWithMbUnitDataContext db = new TestingApplicationsWithMbUnitDataContext();
            db.ExecuteCommand("TRUNCATE TABLE [Order Details]", "");
            //db.ExecuteCommand("TRUNCATE TABLE Orders", "");  Cannot do this as it is referenced by a Foreign key
            db.ExecuteCommand("DELETE FROM Orders", "");
            db.ExecuteCommand("DELETE FROM Products", "");
            db.ExecuteCommand("DELETE FROM Categories", "");

            //Problem is its easy to forget what the method creates (InsertOrder also inserts a Product and Category).
        }

        [Test]
        public void InsertOrder()
        {
            TestingApplicationsWithMbUnitDataContext db = new TestingApplicationsWithMbUnitDataContext();
            int count = db.Orders.Count();
            Console.WriteLine("Count in database: " + count);

            Order o = TestHelper.InsertOrder();
            Console.WriteLine(o.OrderID);
        }
    }


    [TestFixture]
    public class ProblemsWithRollback_RESEED
    {
        //Reason why I'm executing script is incase other tests do not clean up
        //after themselves or expect the database to be empty        
        [SetUp]
        public void Setup()
        {
            TestingApplicationsWithMbUnitDataContext db = new TestingApplicationsWithMbUnitDataContext();
            db.ExecuteCommand("TRUNCATE TABLE [Order Details]", "");
            db.ExecuteCommand("DELETE FROM Orders", "");
            db.ExecuteCommand("DELETE FROM Products", "");
            db.ExecuteCommand("DELETE FROM Categories", "");
            db.ExecuteCommand("DBCC CHECKIDENT (Orders, RESEED, 0)", "");
            db.ExecuteCommand("DBCC CHECKIDENT (Products, RESEED, 0)", "");
        }

        [TearDown]
        public void Teardown()
        {
            TestingApplicationsWithMbUnitDataContext db = new TestingApplicationsWithMbUnitDataContext();
            db.ExecuteCommand("TRUNCATE TABLE [Order Details]", "");
            db.ExecuteCommand("DELETE FROM Orders", "");
            db.ExecuteCommand("DELETE FROM Products", "");
            db.ExecuteCommand("DELETE FROM Categories", "");
            db.ExecuteCommand("DBCC CHECKIDENT (Orders, RESEED, 0)", "");
            db.ExecuteCommand("DBCC CHECKIDENT (Products, RESEED, 0)", "");

            //Problem is its easy to forget what the method creates (InsertOrder also inserts a Product and Category).

            //db.ExecuteCommand(new StreamReader("Other\\rollback.sql").ReadToEnd(), "");
        }

        [Test]
        public void InsertOrder()
        {
            TestingApplicationsWithMbUnitDataContext db = new TestingApplicationsWithMbUnitDataContext();
            int count = db.Orders.Count();
            Console.WriteLine("Count in database: " + count);

            Order o = TestHelper.InsertOrder();
            Console.WriteLine(o.OrderID);
        }
    }
}
