﻿using System.Linq;
using System.Collections.Generic;

namespace DataAccess
{
    public class LinqProductRepository : IProductRepository
    {
        #region IProductRepository Members

        public List<Category> GetCategories()
        {
            //return new List<Category>();

            using (TestingApplicationsWithMbUnitDataContext db = CreateDataContext())
            {
                var query = from c in db.Categories
                            select c;
                return query.ToList();
            }
        }

        public Category GetCategory(string categoryName)
        {
            using (TestingApplicationsWithMbUnitDataContext db = CreateDataContext())
            {
                Category category = db.Categories.Single(c => c.CategoryName == categoryName);
                return category;
            }
        }

        public List<Product> GetProductsForCategory(Category c)
        {
            using (TestingApplicationsWithMbUnitDataContext db = CreateDataContext())
            {
                var query = from prod in db.Products
                            join cate in db.Categories on prod.CategoryID equals cate.CategoryID
                            where cate.CategoryID == c.CategoryID
                            select prod;

                return query.ToList();
            }
        }

        public Product GetProduct(int? productID)
        {
            using (TestingApplicationsWithMbUnitDataContext db = CreateDataContext())
            {
                Product product = db.Products.Single(p => p.ProductID == productID);
                return product;
            }
        }

        public Category GetCategoryById(int categoryId)
        {
            using (TestingApplicationsWithMbUnitDataContext db = CreateDataContext())
            {
                Category category = db.Categories.Single(c => c.CategoryID == categoryId);
                return category;
            }
        }


        #endregion

        private TestingApplicationsWithMbUnitDataContext CreateDataContext()
        {
            return new TestingApplicationsWithMbUnitDataContext();
        }

        #region IProductRepository Members


        public List<Product> GetAllProducts()
        {
            using (TestingApplicationsWithMbUnitDataContext db = CreateDataContext())
            {
                var query = from p in db.Products
                            select p;
                return query.ToList();
            }
        }

        #endregion

    }
}
