﻿using System;
using System.Data.SqlClient;
using System.IO;
using System.Threading;
using MbUnit.Framework;
using WatiN.Core;

namespace TestingApplicationsWithMbUnit.Tests
{
    [TestFixture(ApartmentState = ApartmentState.STA)]
    public class ListCategoriesNoData
    {
        [TestFixtureSetUp]
        public void DeleteRecords()
        {
            SqlConnection sqlConn = new SqlConnection("Data Source=.;Initial Catalog=TestingApplicationsWithMbUnit;Integrated Security=True");
            SqlCommand sqlCmd = new SqlCommand(new StreamReader("..\\..\\..\\..\\Sql\\Cleanup.sql").ReadToEnd(), sqlConn);
            sqlConn.Open();
            sqlCmd.ExecuteNonQuery();
            sqlConn.Close();
        }

        [Test]
        public void ListCategories_NoData_FriendlyError()
        {
            using (IE ie = new IE("http://localhost:49946/TestingApplicationsWithMbUnit/ListCategories.aspx"))
            {
                bool result = ie.Text.Contains("No data was returned.");
                Assert.IsTrue(result, "Does not display correct message!");
            }
        }
    }
        
        
        
   [TestFixture(ApartmentState = ApartmentState.STA)]
    public class ListCategoriesTests
    {
        [TestFixtureSetUp]
        public void InsertData()
        {
            SqlConnection sqlConn = new SqlConnection("Data Source=.;Initial Catalog=TestingApplicationsWithMbUnit;Integrated Security=True");
            SqlCommand sqlCmd = new SqlCommand(new StreamReader("..\\..\\..\\..\\Sql\\SampleData.sql").ReadToEnd(), sqlConn);
            sqlConn.Open();
            sqlCmd.ExecuteNonQuery();
            sqlConn.Close();
        }

        [TestFixtureTearDown]
        public void DeleteData()
        {
            SqlConnection sqlConn = new SqlConnection("Data Source=.;Initial Catalog=TestingApplicationsWithMbUnit;Integrated Security=True");
            SqlCommand sqlCmd = new SqlCommand(new StreamReader("..\\..\\..\\..\\Sql\\Cleanup.sql").ReadToEnd(), sqlConn);
            sqlConn.Open();
            sqlCmd.ExecuteNonQuery();
            sqlConn.Close();
        }

        [Test]
        public void ListCategories_StandardResponse_HasHeader()
        {
            using (IE ie = new IE("http://localhost:49946/TestingApplicationsWithMbUnit/ListCategories.aspx"))
            {
                bool result = ie.Text.Contains("List Categories");
                Assert.IsTrue(result, "Does not contain header");
                Console.WriteLine(ie.Text);
            }
        }

        [Test]
        public void ListCategories_StandardResponse_ContainsDatabaseCategory()
        {
            using (IE ie = new IE("http://localhost:49946/TestingApplicationsWithMbUnit/ListCategories.aspx"))
            {
                bool result = ie.Text.Contains("Database");
                Assert.IsTrue(result, "Does not contain category");
                Console.WriteLine(ie.Text);
            }
        }

        [Test]
        public void ListCategories_StandardResponse_HasLinkToProduct()
        {
            using (IE ie = new IE("http://localhost:49946/TestingApplicationsWithMbUnit/ListCategories.aspx"))
            {
                string url = ie.Link(Find.ByText("Database")).Url;

                StringAssert.Contains(url, "ListProductInCategories.aspx");
                StringAssert.Contains(url, "ID=1");
            }
        }
    }
}
